# Conda Store

[![Documentation Status](https://readthedocs.org/projects/conda-store/badge/?version=latest)](https://conda-store.readthedocs.io/en/latest/?badge=latest)

A client library for interacting with a Conda-Store server. See the
[documentation](https://conda-store.readthedocs.io/en/latest/) for
more information. The client library provides a CLI for interacting
with conda-store.

Currently this part of conda-store is not well developed.
